==> phylo-matt-0.5.2.tar.gz: phylo-matt-0.5.2/README.md <==
# MATT - A FRAMEWORK FOR MODIFYING AND TESTING TOPOLOGIES

[![PyPI version](https://badge.fury.io/py/phylo-matt.svg)](https://pypi.org/project/phylo-matt/)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
![Github Build](https://github.com/BIONF/MATT/workflows/build/badge.svg)

![MATT](https://github.com/BIONF/MATT/blob/master/matt/static/logo.png)

# Table of Contents
* [Installation](#installation)
* [Usage](#usage)
* [Contribution](#contribution)
* [License](#license)
* [Citation](#citation)
* [Contact](contact)

# Installation
*MATT* is distributed as a python package called *phylo-matt*. *MATT* requires a
[Python](https://www.python.org/downloads/) version of 3.5 or higher.

Once python and the included package manager are installed, *MATT* can be installed using the `pip` command in a
console:
```
pip install phylo-matt
```

# Usage
After *MATT* has been installed it can be launched using the `matt` command in a console:
```
matt
```

This will start *MATT* and open `http://localhost:5000` in the preferred browser.

Once open *MATT* can be used via the GUI in the browser.

Make sure to set all the needed options under the options tab and import the alignment and tree files.

After a tree has been constructed or imported the tree can be viewed in the main window and under the overview tab,
snapshots can be saved under the snapshots tab and different tree topologies can be tested under the test tab.

# Contribution
Any bug reports, comments and suggestions are highly appreciated. Please
[open an issue on GitHub](https://github.com/BIONF/MATT/issues/new) or contact us via [email](mailto:jeffgower98@gmail.com).

# License
*MATT* is licensed under the [GNU General Public License v3.0](https://github.com/BIONF/MATT/blob/mater/LICENSE).

# Citation
WIP

# Contact
For further support or bug reports please contact us via [email](mailto:jeffgower98@gmail.com).

==> phylo-matt-0.6.2.tar.gz: phylo-matt-0.6.2/README.md <==
# MATT - A FRAMEWORK FOR MODIFYING AND TESTING TOPOLOGIES

[![PyPI version](https://badge.fury.io/py/phylo-matt.svg)](https://pypi.org/project/phylo-matt/)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
![Github Build](https://github.com/BIONF/MATT/workflows/build/badge.svg)

![MATT](https://github.com/BIONF/MATT/blob/master/matt/static/logo.png)

# Table of Contents
* [Installation](#installation)
* [Usage](#usage)
* [Contribution](#contribution)
* [License](#license)
* [Citation](#citation)
* [Contact](contact)

# Installation
*MATT* is distributed as a python package called *phylo-matt*. *MATT* requires a
[Python](https://www.python.org/downloads/) version of 3.5 or higher.

Once python and the included package manager are installed, *MATT* can be installed using the `pip` command in a
console:
```
pip install phylo-matt
```
If you run into errors, try:
```
pip install phylo-matt --user
```

# Usage
After *MATT* has been installed it can be launched using the `matt` command in a console:
```
matt
```

This will start *MATT* and open `http://localhost:5000` in the preferred browser.

Once open *MATT* can be used via the GUI in the browser.

Make sure to set all the needed options under the options tab and import the alignment and tree files.

After a tree has been constructed or imported the tree can be viewed in the main window and under the overview tab,
snapshots can be saved under the snapshots tab and different tree topologies can be tested under the test tab.

To close *MATT* again, simply kill the server by hitting Ctrl+C in the console.

# Contribution
Any bug reports, comments and suggestions are highly appreciated. Please
[open an issue on GitHub](https://github.com/BIONF/MATT/issues/new) or contact us via [email](mailto:jeffgower98@gmail.com).

# License
*MATT* is licensed under the [GNU General Public License v3.0](https://github.com/BIONF/MATT/blob/mater/LICENSE).

# Citation
WIP

# Contact
For further support or bug reports please contact us via [email](mailto:jeffgower98@gmail.com).
